@@ -25,6 +25,7 @@ import six
 
 from paramiko.message import Message
 from paramiko.pkey import PKey
+from paramiko.py3compat import b
 from paramiko.ssh_exception import SSHException, PasswordRequiredException
 
 
@@ -45,18 +46,39 @@ def unpad(data):
 
 
 class Ed25519Key(PKey):
-    def __init__(self, msg=None, data=None, filename=None, password=None):
+    """
+    Representation of an `Ed25519 <https://ed25519.cr.yp.to/>`_ key.
+
+    .. note::
+        Ed25519 key support was added to OpenSSH in version 6.5.
+
+    .. versionadded:: 2.2
+    .. versionchanged:: 2.3
+        Added a ``file_obj`` parameter to match other key classes.
+    """
+
+    def __init__(
+        self, msg=None, data=None, filename=None, password=None, file_obj=None
+    ):
+        self.public_blob = None
         verifying_key = signing_key = None
         if msg is None and data is not None:
             msg = Message(data)
         if msg is not None:
-            if msg.get_text() != "ssh-ed25519":
-                raise SSHException("Invalid key")
+            self._check_type_and_load_cert(
+                msg=msg,
+                key_type="ssh-ed25519",
+                cert_type="ssh-ed25519-cert-v01@openssh.com",
+            )
             verifying_key = nacl.signing.VerifyKey(msg.get_binary())
         elif filename is not None:
             with open(filename, "r") as f:
                 data = self._read_private_key("OPENSSH", f)
-                signing_key = self._parse_signing_key_data(data, password)
+        elif file_obj is not None:
+            data = self._read_private_key("OPENSSH", file_obj)
+
+        if filename or file_obj:
+            signing_key = self._parse_signing_key_data(data, password)
 
         if signing_key is None and verifying_key is None:
             raise ValueError("need a key")
@@ -66,6 +88,7 @@ class Ed25519Key(PKey):
 
     def _parse_signing_key_data(self, data, password):
         from paramiko.transport import Transport
+
         # We may eventually want this to be usable for other key types, as
         # OpenSSH moves to it, but for now this is just for Ed25519 keys.
         # This format is described here:
@@ -113,7 +136,7 @@ class Ed25519Key(PKey):
         else:
             cipher = Transport._cipher_info[ciphername]
             key = bcrypt.kdf(
-                password=password,
+                password=b(password),
                 salt=bcrypt_salt,
                 desired_key_bytes=cipher["key-size"] + cipher["block-size"],
                 rounds=bcrypt_rounds,
@@ -122,9 +145,9 @@ class Ed25519Key(PKey):
                 ignore_few_rounds=True,
             )
             decryptor = Cipher(
-                cipher["class"](key[:cipher["key-size"]]),
-                cipher["mode"](key[cipher["key-size"]:]),
-                backend=default_backend()
+                cipher["class"](key[: cipher["key-size"]]),
+                cipher["mode"](key[cipher["key-size"] :]),
+                backend=default_backend(),
             ).decryptor()
             private_data = (
                 decryptor.update(private_ciphertext) + decryptor.finalize()
@@ -146,8 +169,10 @@ class Ed25519Key(PKey):
             signing_key = nacl.signing.SigningKey(key_data[:32])
             # Verify that all the public keys are the same...
             assert (
-                signing_key.verify_key.encode() == public == public_keys[i] ==
-                key_data[32:]
+                signing_key.verify_key.encode()
+                == public
+                == public_keys[i]
+                == key_data[32:]
             )
             signing_keys.append(signing_key)
             # Comment, ignore.
